# kolena-agents.-generated.openapi-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The `kolena_agents._generated.openapi_client` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.0
- Package version: 1.0.0
- Generator version: 7.13.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 2.1.0, < 3.0.0
* python-dateutil >= 2.8.2
* pydantic >= 2
* typing-extensions >= 4.7.1

## Getting Started

In your own code, to use this library to connect and interact with kolena-agents.-generated.openapi-client,
you can run the following:

```python

import kolena_agents._generated.openapi_client
from kolena_agents._generated.openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = kolena_agents._generated.openapi_client.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: HTTPBearer
configuration = kolena_agents._generated.openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with kolena_agents._generated.openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = kolena_agents._generated.openapi_client.ClientApi(api_client)
    agent_id = 56 # int | 
    files = None # List[bytearray] | List of files for the run. A single request can have a maximum of 100 files. Each file can have maximum 125MB
    user_defined_id = 'user_defined_id_example' # str |  (optional)

    try:
        # Add Agent Run
        api_response = api_instance.add_agent_run_api_v1_client_agents_agent_id_runs_post(agent_id, files, user_defined_id=user_defined_id)
        print("The response of ClientApi->add_agent_run_api_v1_client_agents_agent_id_runs_post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ClientApi->add_agent_run_api_v1_client_agents_agent_id_runs_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ClientApi* | [**add_agent_run_api_v1_client_agents_agent_id_runs_post**](kolena_agents/_generated/openapi_client/docs/ClientApi.md#add_agent_run_api_v1_client_agents_agent_id_runs_post) | **POST** /api/v1/client/agents/{agent_id}/runs | Add Agent Run
*ClientApi* | [**delete_agent_run_api_v1_client_agents_agent_id_runs_run_id_delete**](kolena_agents/_generated/openapi_client/docs/ClientApi.md#delete_agent_run_api_v1_client_agents_agent_id_runs_run_id_delete) | **DELETE** /api/v1/client/agents/{agent_id}/runs/{run_id} | Delete Agent Run
*ClientApi* | [**get_agent_api_v1_client_agents_agent_id_get**](kolena_agents/_generated/openapi_client/docs/ClientApi.md#get_agent_api_v1_client_agents_agent_id_get) | **GET** /api/v1/client/agents/{agent_id}/ | Get Agent
*ClientApi* | [**get_agent_api_v1_client_agents_agent_id_get_0**](kolena_agents/_generated/openapi_client/docs/ClientApi.md#get_agent_api_v1_client_agents_agent_id_get_0) | **GET** /api/v1/client/agents/{agent_id} | Get Agent
*ClientApi* | [**get_agent_run_api_v1_client_agents_agent_id_runs_run_id_get**](kolena_agents/_generated/openapi_client/docs/ClientApi.md#get_agent_run_api_v1_client_agents_agent_id_runs_run_id_get) | **GET** /api/v1/client/agents/{agent_id}/runs/{run_id} | Get Agent Run
*ClientApi* | [**list_agent_runs_api_v1_client_agents_agent_id_runs_get**](kolena_agents/_generated/openapi_client/docs/ClientApi.md#list_agent_runs_api_v1_client_agents_agent_id_runs_get) | **GET** /api/v1/client/agents/{agent_id}/runs | List Agent Runs
*ClientApi* | [**list_agents_api_v1_client_agents_get**](kolena_agents/_generated/openapi_client/docs/ClientApi.md#list_agents_api_v1_client_agents_get) | **GET** /api/v1/client/agents/ | List Agents
*ClientApi* | [**list_agents_api_v1_client_agents_get_0**](kolena_agents/_generated/openapi_client/docs/ClientApi.md#list_agents_api_v1_client_agents_get_0) | **GET** /api/v1/client/agents | List Agents
*ClientApi* | [**sample_results_api_v1_client_agents_agent_id_sample_get**](kolena_agents/_generated/openapi_client/docs/ClientApi.md#sample_results_api_v1_client_agents_agent_id_sample_get) | **GET** /api/v1/client/agents/{agent_id}/sample | Sample Results
*ClientApi* | [**stream_results_api_v1_client_agents_agent_id_stream_get**](kolena_agents/_generated/openapi_client/docs/ClientApi.md#stream_results_api_v1_client_agents_agent_id_stream_get) | **GET** /api/v1/client/agents/{agent_id}/stream | Stream Results


## Documentation For Models

 - [Agent](kolena_agents/_generated/openapi_client/docs/Agent.md)
 - [AgentRun](kolena_agents/_generated/openapi_client/docs/AgentRun.md)
 - [AgentRunResult](kolena_agents/_generated/openapi_client/docs/AgentRunResult.md)
 - [AgentRunResultMetadata](kolena_agents/_generated/openapi_client/docs/AgentRunResultMetadata.md)
 - [AgentRunResultMetadataCitation](kolena_agents/_generated/openapi_client/docs/AgentRunResultMetadataCitation.md)
 - [AgentRunStatus](kolena_agents/_generated/openapi_client/docs/AgentRunStatus.md)
 - [CellResultUserData](kolena_agents/_generated/openapi_client/docs/CellResultUserData.md)
 - [CellResultUserInput](kolena_agents/_generated/openapi_client/docs/CellResultUserInput.md)
 - [HTTPValidationError](kolena_agents/_generated/openapi_client/docs/HTTPValidationError.md)
 - [ListAgentRunsResponse](kolena_agents/_generated/openapi_client/docs/ListAgentRunsResponse.md)
 - [ListAgentsResponse](kolena_agents/_generated/openapi_client/docs/ListAgentsResponse.md)
 - [Prompt](kolena_agents/_generated/openapi_client/docs/Prompt.md)
 - [PromptDocument](kolena_agents/_generated/openapi_client/docs/PromptDocument.md)
 - [ValidationError](kolena_agents/_generated/openapi_client/docs/ValidationError.md)
 - [ValidationErrorLocInner](kolena_agents/_generated/openapi_client/docs/ValidationErrorLocInner.md)
 - [Value](kolena_agents/_generated/openapi_client/docs/Value.md)
 - [ValueAnyOfInnerValue](kolena_agents/_generated/openapi_client/docs/ValueAnyOfInnerValue.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="HTTPBearer"></a>
### HTTPBearer

- **Type**: Bearer authentication


## Author




